@@ -19,7 +19,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -311,6 +311,11 @@ sub process_source {
     my $was_tidied = !$error && ( $new_contents ne $orig_contents );
     if ( $was_tidied && $self->check_only ) {
         $error = "*** needs tidying";
+        my $diff = q{};
+        foreach $plugin (@plugins) {
+            $diff = $plugin->diff( $diff, $orig_contents, $new_contents, $path );
+        }
+        $error .= "\n\n" . $diff if length $diff;
         undef $was_tidied;
     }
 
@@ -530,7 +535,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
